﻿using System;
using System.Globalization;
using System.Web.Mvc;
using Calculator.Models;
using Calculator.Repositories;

namespace Calculator.Controllers
{
    /// <summary>
    /// Основной контроллер приложения.
    /// </summary>
    public class HomeController : Controller
    {
        private readonly ICalculatorRepository _repository;

        public HomeController(ICalculatorRepository repository)
        {
            _repository = repository;
        }

        /// <summary>
        /// Показывает основное окно - калькулятор.
        /// </summary>
        public ActionResult Index()
        {
            return View();
        }

        /// <summary>
        /// Показывает историю вычислений.
        /// </summary>
        public ActionResult History()
        {
            var model = new HistoryModel { Items = _repository.ViewAll() };
            return View(model);
        }

        /// <summary>
        /// Производит вычисления, вызывается из "Calculator.js"
        /// </summary>
        /// <param name="left">Левый операнд</param>
        /// <param name="right">Правый операнд</param>
        /// <param name="operation">Операция</param>
        [HttpPost]
        public ActionResult Calculate(string left, string right, string operation)
        {
            try
            {
                var calculator = new Models.Calculator();
                double result = calculator.Calculate(left, operation, right);

                var item = new OperationHistoryItem {
                    RunAt = DateTime.UtcNow, 
                    Operation = string.Format("{0}{1}{2}", left, operation, right), 
                    Result = result.ToString("0.##")
                };
                _repository.Save(item);

                return Json(new { value = item.Result, message = (string)null });
            }
            catch (Exception ex)
            {
                return Json(new { value = "0", message = ex.Message });
            }
        }

        /// <summary>
        /// Меняет язык приложения.
        /// </summary>
        /// <param name="lang">Новый язык</param>
        /// <param name="returnUrl">URL на который производится редирект после выбора языка</param>
        /// <returns></returns>
        public ActionResult ChangeCulture(string lang, string returnUrl)
        {
            Session["Culture"] = new CultureInfo(lang);
            return Redirect(returnUrl);
        }
    }
}
