﻿using System;
using System.Web.Mvc;
using System.Web.Routing;
using Calculator.Repositories;
using Ninject;
using Ninject.Modules;

namespace Calculator.Controllers
{
    /// <summary>
    /// Фабрика контроллеров, DI с помощью NInject.
    /// </summary>
    public class NinjectControllerFactory : DefaultControllerFactory
    {
        private readonly IKernel _kernel = new StandardKernel(new CalculatorDependencies());

        protected override IController GetControllerInstance(RequestContext requestContext, Type controllerType)
        {
            return (controllerType == null) ? null : (IController) _kernel.Get(controllerType);
        }

        private class CalculatorDependencies : NinjectModule
        {
            public override void Load()
            {
                Bind<ICalculatorRepository>().To<CalculatorRepository>();
            }
        }
    }
}